@@ -1,7 +1,9 @@
 ;; Foreign functions provided by the Linux C library version 6,
 ;; i.e. the GNU C library version 2.0.7.
 ;; Bruno Haible 10.4.1998, 19.4.1998
-;; Sam Steingold 2002-2008
+;; Sam Steingold 2002-2008, 2011
+
+;; NB: quite a few functions here have more portable counterparts in POSIX
 
 (defpackage "LINUX"
   (:modern t)
@@ -67,7 +69,6 @@
 (def-c-type __daddr_t)          ; int
 (def-c-type __caddr_t)          ; c-pointer
 (def-c-type __time_t)           ; long
-(def-c-type __swblk_t)          ; long
 
 (def-c-type __fd_mask ulong)
 (eval-when (load compile eval)
@@ -86,7 +87,7 @@
 
 (def-c-type __key_t)            ; int
 
-(c-lines "#include <bits/ipctypes.h>~%")
+(c-lines "#include <sys/ipc.h>~%")
 (def-c-type __ipc_pid_t)        ; ushort
 
 ; --------------------------- <sys/types.h> -----------------------------------
@@ -648,7 +649,6 @@
 (def-call-out calloc (:arguments (nmemb size_t) (size size_t))
   (:return-type c-pointer))
 (def-call-out free (:arguments (ptr c-pointer)) (:return-type nil))
-(def-call-out cfree (:arguments (ptr c-pointer)) (:return-type nil))
 (def-call-out valloc (:arguments (size size_t)) (:return-type c-pointer))
 
 (def-call-out abort (:arguments) (:return-type nil))
@@ -1337,6 +1337,8 @@
 (def-call-out fork (:arguments) (:return-type pid_t))
 (def-call-out vfork (:arguments) (:return-type pid_t))
 
+;; wrap calls to wait & waitpid in POSIX:WITH-SUBPROCESSES
+;; and, better yet, use POSIX:WAIT instead
 (c-lines "#include <sys/wait.h>~%")
 
 (def-call-out wait (:arguments (status (c-ptr int) :out :alloca))
